@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- *  $Id: commands.c,v 1.31 2006/09/22 07:22:47 smorlat Exp $
+ *  $Id: commands.c,v 1.34 2007/02/20 10:17:13 smorlat Exp $
  *
  *  Copyright (C) 2006  Sandro Santilli <strk@keybit.net>
  *  Copyright (C) 2004  Simon MORLAT <simon.morlat@linphone.org>
@@ -68,6 +68,8 @@ static void linphonec_friend_display(LinphoneFriend *fr);
 static int linphonec_friend_list(LinphoneCore *lc, char *arg);
 static void linphonec_display_command_help(LPC_COMMAND *cmd);
 static int linphonec_friend_call(LinphoneCore *lc, unsigned int num);
+static int linphonec_friend_add(LinphoneCore *lc, const char *name, const char *addr);
+static int linphonec_friend_delete(LinphoneCore *lc, int num);
 
 /* Command table management */
 static LPC_COMMAND *lpc_find_command(const char *name);
@@ -132,7 +134,11 @@ LPC_COMMAND commands[] = {
                 NULL },
 	{ "friend", lpc_cmd_friend, "Manage friends",
 		"'friend list [<pattern>]'    : list friends.\n"
-		"'friend call <index>         : call a friend."
+		"'friend call <index>'        : call a friend.\n"
+		"'friend add <name> <addr>'   : add friend, <name> must be quoted to include\n"
+	    "                               spaces, <addr> has \"sip:\" added if it isn't\n"
+	    "                               there.  Don't use '<' '>' around <addr>.\n"
+		"'friend delete <index>'      : remove friend, 'all' removes all\n"
 	},
 	{ "play", lpc_cmd_play, "play from a wav file",
 		"This feature is available only in file mode (see 'help soundcard')\n"
@@ -409,6 +415,36 @@ lpc_cmd_firewall(LinphoneCore *lc, char *args)
 	return 1;
 }
 
+/* Helper function for processing freind names */
+static int
+lpc_friend_name(char **args, char **name)
+{
+	/* Use space as a terminator unless quoted */
+	if (('"' == **args) || ('\'' == **args)){
+		char *end;
+		char delim = **args;
+		(*args)++;
+		end = (*args);
+		while ((delim != *end) && ('\0' != *end)) end++;
+		if ('\0' == *end) {
+			fprintf(stderr, "Mismatched quotes\n");
+			return 0;
+		}
+		*name = *args;
+		*end = '\0';
+		*args = ++end;
+	} else {
+		*name = strsep(args, " ");
+		
+		if (NULL == *args) { /* Means there was no separator */
+			fprintf(stderr, "Either name or address is missing\n");
+			return 0;
+		}
+		if (NULL == *name) return 0;
+	}
+	return 1;
+}
+
 static int
 lpc_cmd_friend(LinphoneCore *lc, char *args)
 {
@@ -435,7 +471,55 @@ lpc_cmd_friend(LinphoneCore *lc, char *args)
 		linphonec_friend_call(lc, friend_num);
 		return 1;
 	}
+	else if ( !strncmp(args, "delete", 6) )
+	{
+		args+=6;
+		if ( ! *args ) return 0;
+		while (*args == ' ') args++;
+		if ( ! *args ) return 0;
+		if (!strncmp(args, "all", 3))
+		{
+			friend_num = -1;
+		} 
+		else
+		{
+			friend_num = strtol(args, NULL, 10);
+			if ( errno == ERANGE ) {
+				printf("Invalid friend number\n");
+				return 0;
+			}
+		}
+		linphonec_friend_delete(lc, friend_num);
+		return 1;
+	}
+	else if ( !strncmp(args, "add", 3) )
+	{
+		char  *name;
+		char  addr[80];
+		char *addr_p = addr;
+		char *addr_orig;
 
+		args+=3;
+		if ( ! *args ) return 0;
+		while (*args == ' ') args++;
+		if ( ! *args ) return 0;
+		if (!lpc_friend_name(&args,  &name)) return 0;
+
+		while (*args == ' ') args++;
+		if ( ! *args ) return 0;
+		if (isdigit(*args)) {
+			strcpy (addr, "sip:");
+			addr_p = addr + strlen("sip:");
+		}
+		addr_orig = strsep(&args, " ");
+		if (1 <= strlen(addr_orig)) {
+			fprintf(stderr, "A single-digit address is not valid\n");
+			return 0;
+		}
+		strcpy(addr_p, addr_orig);
+		linphonec_friend_add(lc, name, addr);
+		return 1;
+	}
 	return 0;
 }
 
@@ -946,6 +1030,46 @@ linphonec_friend_call(LinphoneCore *lc, unsigned int num)
 	return 1;
 }
 
+static int
+linphonec_friend_add(LinphoneCore *lc, const char *name, const char *addr)
+{
+	LinphoneFriend *newFriend;
+
+	char url[PATH_MAX];
+
+	snprintf(url, PATH_MAX, "%s <%s>", name, addr);
+	newFriend = linphone_friend_new_with_addr(url);
+	linphone_core_add_friend(lc, newFriend);
+	return 0;
+}
+
+static int
+linphonec_friend_delete(LinphoneCore *lc, int num)
+{
+	MSList *friend = linphone_core_get_friend_list(lc);
+	unsigned int n;
+
+	for(n=0; friend!=NULL; friend=ms_list_next(friend), ++n )
+	{
+		if ( n == num )
+		{
+			linphone_core_remove_friend(lc, friend->data);
+			return 0;
+		}
+	}
+
+	if (-1 == num) 
+	{
+		unsigned int i;
+		for (i = 0 ; i < n ; i++)
+			linphonec_friend_delete(lc, 0);
+		return 0;
+	}
+
+	printf("No such friend %u\n", num);
+	return 1;
+}
+
 static void
 linphonec_display_command_help(LPC_COMMAND *cmd)
 {
@@ -980,6 +1104,9 @@ lpc_find_command(const char *name)
 /****************************************************************************
  *
  * $Log: commands.c,v $
+ * Revision 1.34  2007/02/20 10:17:13  smorlat
+ * linphonec friends patch2
+ *
  * Revision 1.31  2006/09/22 07:22:47  smorlat
  * linphonecore api changes.
  *
