@@ -98,7 +98,8 @@ void call_accept(Call *call)
 		hellofile=call->root->file_path16000hz;
 	}else hellofile=call->root->file_path8000hz;
 	eXosip_answer_call_with_body(call->did,200,"application/sdp",call->sdpc->answerstr);
- 	call->audio_stream=audio_stream_start_with_files(call->profile,call->audio.localport,
+ 	call->audio_stream=audio_stream_new(call->audio.localport,call->root->ipv6);
+	audio_stream_start_with_files(call->audio_stream, call->profile,
 				call->audio.remaddr,call->audio.remoteport,call->audio.pt,20,hellofile,record_file);
 	call_count++;
 #ifdef VIDEO_ENABLED
@@ -221,6 +222,7 @@ void sipomatic_init(Sipomatic *obj, char *url, bool_t ipv6)
 	int port=5064;
 	
 	eXosip_enable_ipv6(ipv6);
+	obj->ipv6=ipv6;
 	
 	if (url==NULL){
 		url=getenv("SIPOMATIC_URL");
