@@ -246,12 +246,16 @@ void linphone_register_authentication_required(LinphoneCore *lc,eXosip_event_t *
 	ms_return_if_fail(resp!=NULL);
 	cfg=linphone_core_get_proxy_config_from_rid(lc,ev->rid);
 	ms_return_if_fail(cfg!=NULL);
+	if (cfg->auth_pending)
+		gstate_new_state(lc, GSTATE_REG_FAILED, "Authentication required");
 	if (linphone_process_authentication(lc,resp,cfg,cfg->auth_pending)){
 		/* we have the information, so retry the register */
 		eXosip_lock();
 		eXosip_register(ev->rid,-1);
 		eXosip_unlock();
 	}
+	else
+		gstate_new_state(lc, GSTATE_REG_FAILED, "Authentication required");
 	cfg->auth_pending=TRUE;
 }
 
