@@ -1,6 +1,6 @@
 /*
 linphone
-Copyright (C) 2000  Simon MORLAT (simon.morlat@free.fr)
+Copyright (C) 2000  Simon MORLAT (simon.morlat@linphone.org)
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -19,9 +19,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 /* enum lookup code */
 
-#include <netinet/in.h>
-#include <arpa/nameser.h>
-#include <resolv.h>
 #include <errno.h>
 #include <string.h>
 
@@ -29,13 +26,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #define DNS_ANSWER_MAX_SIZE 2048
 
-#undef res_search
-#undef ns_initparse
-#undef ns_parserr
 
-gchar *create_enum_domain(const gchar *number){
+char *create_enum_domain(const char *number){
 	int len=strlen(number);
-	gchar *domain=g_malloc((len*2)+10);
+	char *domain=ms_malloc((len*2)+10);
 	int i,j;
 	
 	for (i=0,j=len-1;j>=0;j--){
@@ -45,15 +39,15 @@ gchar *create_enum_domain(const gchar *number){
 		i++;
 	}
 	strcpy(&domain[i],"e164.arpa");
-	g_message("enum domain for %s is %s",number,domain);
+	ms_message("enum domain for %s is %s",number,domain);
 	return domain;
 }
 
 
-gboolean is_a_number(const char *str){
+bool_t is_a_number(const char *str){
 	char *p=(char *)str;
-	gboolean res=FALSE;
-	gboolean space_found=FALSE;
+	bool_t res=FALSE;
+	bool_t space_found=FALSE;
 	for(;;p++){
 		switch(p[0]){
 			case '9':
@@ -82,7 +76,7 @@ gboolean is_a_number(const char *str){
 	return FALSE;
 }
 //4970072278724
-gboolean is_enum(const gchar *sipaddress, char **enum_domain){
+bool_t is_enum(const char *sipaddress, char **enum_domain){
 	char *p;
 	p=strstr(sipaddress,"sip:");
 	if (p==NULL) return FALSE; /* enum should look like sip:4369959250*/
@@ -98,24 +92,24 @@ gboolean is_enum(const gchar *sipaddress, char **enum_domain){
 
 
 
-gint enum_lookup(const gchar *enum_domain, enum_lookup_res_t **res){
+int enum_lookup(const char *enum_domain, enum_lookup_res_t **res){
 	int err;
 	//char dns_answer[DNS_ANSWER_MAX_SIZE];
 	char *begin,*end;
 	char *host_result, *command;
 	int i;
-	gboolean forkok;
+	bool_t forkok;
 	/*
 	ns_msg handle;
 	int count;
 	
 	memset(&handle,0,sizeof(handle));
 	*res=NULL;
-	g_message("Resolving %s...",enum_domain);
+	ms_message("Resolving %s...",enum_domain);
 	
 	err=res_search(enum_domain,ns_c_in,ns_t_naptr,dns_answer,DNS_ANSWER_MAX_SIZE);
 	if (err<0){
-		g_warning("Error resolving enum:",herror(h_errno));
+		ms_warning("Error resolving enum:",herror(h_errno));
 		return -1;
 	}
 	ns_initparse(dns_answer,DNS_ANSWER_MAX_SIZE,&handle);
@@ -125,54 +119,54 @@ gint enum_lookup(const gchar *enum_domain, enum_lookup_res_t **res){
 		ns_rr rr;
 		memset(&rr,0,sizeof(rr));
 		ns_parserr(&handle,ns_s_an,i,&rr);
-		g_message("data=%s",ns_rr_rdata(rr));
+		ms_message("data=%s",ns_rr_rdata(rr));
 	}
 	*/
-	command=g_strdup_printf("host -t naptr %s",enum_domain);
-	forkok=g_spawn_command_line_sync(command,&host_result,NULL,&err,NULL);
-	g_free(command);
+	command=ms_strdup_printf("host -t naptr %s",enum_domain);
+	forkok=lp_spawn_command_line_sync(command,&host_result,&err);
+	ms_free(command);
 	if (forkok){
 		if (err!=0){
-			g_warning("Host exited with %i error status.",err);
+			ms_warning("Host exited with %i error status.",err);
 			return -1;
 		}
 	}else{
-		g_warning("Could not spawn the \'host\' command.");
+		ms_warning("Could not spawn the \'host\' command.");
 		return -1;
 	}		
-	g_message("Answer received from dns (err=%i): %s",err,host_result);
+	ms_message("Answer received from dns (err=%i): %s",err,host_result);
 	
 	begin=strstr(host_result,"sip:");
 	if (begin==0) {
-		g_warning("No sip address found in dns naptr answer.");
+		ms_warning("No sip address found in dns naptr answer.");
 		return -1;
 	}
-	*res=g_malloc0(sizeof(enum_lookup_res_t));
+	*res=ms_malloc0(sizeof(enum_lookup_res_t));
 	err=0;
 	for(i=0;i<MAX_ENUM_LOOKUP_RESULTS;i++){
 		end=strstr(begin,"!");
 		if (end==NULL) goto parse_error;
 		end[0]='\0';
-		(*res)->sip_address[i]=g_strdup(begin);
+		(*res)->sip_address[i]=ms_strdup(begin);
 		err++;
 		begin=strstr(end+1,"sip:");
 		if (begin==NULL) break;
 	}
-	g_free(host_result);
+	ms_free(host_result);
 	return err;
 
 	parse_error:
-		g_free(*res);
-		g_free(host_result);
+		ms_free(*res);
+		ms_free(host_result);
 		*res=NULL;
-		g_warning("Parse error in enum_lookup().");
+		ms_warning("Parse error in enum_lookup().");
 		return -1;
 }
 
 void enum_lookup_res_free(enum_lookup_res_t *res){
 	int i;
 	for (i=0;i<MAX_ENUM_LOOKUP_RESULTS;i++){
-		if (res->sip_address[i]!=NULL) g_free(res->sip_address[i]);
+		if (res->sip_address[i]!=NULL) ms_free(res->sip_address[i]);
 	}
-	g_free(res);
+	ms_free(res);
 }
