@@ -56,6 +56,7 @@ int linphone_call_accepted(LinphoneCore *lc,int id, const char *sdpbody)
 	sdp_context_read_answer(lc->call->sdpctx,sdpbody);
 	lc->vtable.show(lc);
 	lc->vtable.display_status(lc,_("Connected."));
+	gstate_new_state(lc, GSTATE_CALL_OUT_CONNECTED, NULL);
 	lc->call->state=LCStateAVRunning;
 	if (lc->ringstream!=NULL){
 		ring_stop(lc->ringstream);
@@ -86,6 +87,7 @@ int linphone_call_terminated(LinphoneCore *lc, eXosip_event_t *ev)
 	linphone_core_stop_media_streams(lc);
 	lc->vtable.show(lc);
 	lc->vtable.display_status(lc,_("Call terminated."));
+	gstate_new_state(lc, GSTATE_CALL_END, NULL);
 	if (lc->vtable.bye_recv!=NULL)
 		lc->vtable.bye_recv(lc,ev->remote_uri);
 	if (lc->call!=NULL){
@@ -103,6 +105,7 @@ int linphone_call_released(LinphoneCore *lc, int cid){
 		linphone_call_destroy(lc->call);
 		lc->call=NULL;
 		lc->vtable.display_status(lc,_("Could not reach destination."));
+		gstate_new_state(lc, GSTATE_CALL_ERROR, NULL);
 	}
 	return 0;
 }
@@ -180,8 +183,11 @@ int linphone_call_failure(LinphoneCore *lc,int cid, int code)
 		lc->ringstream=NULL;
 	}
 	linphone_core_stop_media_streams(lc);
-	if (lc->call!=NULL) linphone_call_destroy(lc->call);
-	lc->call=NULL;
+	if (lc->call!=NULL) {
+		linphone_call_destroy(lc->call);
+		gstate_new_state(lc, GSTATE_CALL_ERROR, NULL);
+		lc->call=NULL;
+	}
 	return 0;
 }
 
@@ -316,14 +322,19 @@ int linphone_inc_new_call(LinphoneCore *lc, eXosip_event_t *ev)
 			linphone_call_set_state(lc->call,LCStateRinging);
 			{
 				char *tmp;
-				if (from_2char_without_params(from_url,&tmp)==0){
-					barmesg=ortp_strdup_printf("%s %s",tmp,_("is contacting you."));
-					lc->vtable.show(lc);
-					lc->vtable.display_status(lc,barmesg);
-					lc->vtable.inv_recv(lc,tmp);
-					ms_free(barmesg);
-					osip_free(tmp);
+				if (from_2char_without_params(from_url,&tmp)!=0){
+					tmp=ms_strdup("Unknown user");
 				}
+				linphone_core_init_media_streams(lc);
+				barmesg=ortp_strdup_printf("%s %s",tmp,_("is contacting you."));
+				lc->vtable.show(lc);
+				lc->vtable.display_status(lc,barmesg);
+				gstate_new_state(lc, GSTATE_CALL_IN_INVITE, tmp);
+				lc->vtable.inv_recv(lc,tmp);
+				ms_free(barmesg);
+				osip_free(tmp);
+				
+				gstate_new_state(lc, GSTATE_CALL_IN_INVITE, NULL);
 			}
 		break;
 		default:	
@@ -488,8 +499,10 @@ SupportLevel linphone_payload_is_supported(LinphoneCore *lc, sdp_payload_t *payl
 			if (payload->b_as_bandwidth!=0){
 				/*obey to remote bandwidth constraint AND our own upbandwidth constraint*/
 				rtppayload->normal_bitrate=1000*get_min_bandwidth(
-					payload->b_as_bandwidth,
-					ubw);
+					payload->b_as_bandwidth, ubw);
+			}else{
+				/*limit to upload bandwidth if exist, else no limit*/
+				rtppayload->normal_bitrate=(ubw>0)? 1000*ubw : -1;
 			}
 			/* but anyway give our download bandwidth constraint*/
 			payload->b_as_bandwidth=(dbw>0) ? dbw : 0;
@@ -647,7 +660,7 @@ void linphone_call_proceeding(LinphoneCore *lc, int cid, int did){
 
 void linphone_call_ringing(LinphoneCore *lc, eXosip_event_t *ev){
 	
-	if (lc->audiostream!=NULL) return; /*already listening to remote host */
+	if (lc->audiostream->ticker!=NULL) return; /*already listening to remote host */
 	linphone_call_proceeding(lc,ev->cid,ev->did);
 	
 	if (ev->status_code==180){
@@ -677,6 +690,7 @@ void linphone_registration_faillure(LinphoneCore *lc,eXosip_event_t *ev)
 			if (strlen(ev->reason_phrase)==0) msg=ortp_strdup_printf(_("Registration on %s failed (timeout)."),ev->req_uri);
 			else msg=ev->reason_phrase;
 			lc->vtable.display_status(lc,msg);
+			gstate_new_state(lc, GSTATE_REG_FAILED, msg);
 			if ( msg != ev->reason_phrase ) ms_free(msg);
 	}
 	
@@ -684,13 +698,14 @@ void linphone_registration_faillure(LinphoneCore *lc,eXosip_event_t *ev)
 
 void linphone_registration_success(LinphoneCore *lc,eXosip_event_t *ev){
 	LinphoneProxyConfig *cfg;
-	char *msg=ms_strdup_printf(_("Registration on %s sucessful."),ev->req_uri);
+	char *msg=ms_strdup_printf(_("Registration on %s successful."),ev->req_uri);
 	lc->vtable.display_status(lc,msg);
 	ms_free(msg);
 	cfg=linphone_core_get_proxy_config_from_rid(lc,ev->rid);
 	ms_return_if_fail(cfg!=NULL);
 	cfg->auth_pending=FALSE;
 	cfg->registered=TRUE;
+	gstate_new_state(lc, GSTATE_REG_OK, NULL);
 }
 
 void linphone_core_process_event(LinphoneCore *lc,eXosip_event_t *ev)
