@@ -90,7 +90,7 @@ void __linphone_friend_do_subscribe(LinphoneFriend *fr){
 	else req_uri=friend;
 	if (fr->sid<0){
 		/* people for which we don't have yet an answer should appear as offline */
-		fr->lc->vtable.notify_recv(fr->lc,(LinphoneFriend*)fr,friend,_("Gone"),"linphone/sip-closed.png");
+		fr->lc->vtable.notify_recv(fr->lc,(LinphoneFriend*)fr,friend,_("Gone"),"sip-closed.png");
 	}
 	eXosip_lock();
 	err=-1;
