@@ -179,7 +179,6 @@ typedef enum _LinphoneCallStatus {
 } LinphoneCallStatus;
 
 typedef struct _LinphoneCallLog{
-	struct _LinphoneCore *lc;
 	LinphoneCallDir dir;
 	LinphoneCallStatus status;
 	char *from;
@@ -301,6 +300,50 @@ void linphone_chat_room_destroy(LinphoneChatRoom *cr);
 void linphone_chat_room_set_user_data(LinphoneChatRoom *cr, void * ud);
 void * linphone_chat_room_get_user_data(LinphoneChatRoom *cr);
 
+/* describes the different groups of states */
+typedef enum _gstate_group {
+  GSTATE_GROUP_POWER,
+  GSTATE_GROUP_REG,
+  GSTATE_GROUP_CALL
+} gstate_group_t;
+
+typedef enum _gstate {
+  /* states for GSTATE_GROUP_POWER */
+  GSTATE_POWER_OFF = 0,        /* initial state */
+  GSTATE_POWER_STARTUP,
+  GSTATE_POWER_ON,
+  GSTATE_POWER_SHUTDOWN,
+  /* states for GSTATE_GROUP_REG */
+  GSTATE_REG_NONE = 10,       /* initial state */
+  GSTATE_REG_OK,
+  GSTATE_REG_FAILED,
+  /* states for GSTATE_GROUP_CALL */
+  GSTATE_CALL_IDLE = 20,      /* initial state */
+  GSTATE_CALL_OUT_INVITE,
+  GSTATE_CALL_OUT_CONNECTED,
+  GSTATE_CALL_IN_INVITE,
+  GSTATE_CALL_IN_CONNECTED,
+  GSTATE_CALL_END,
+  GSTATE_CALL_ERROR
+} gstate_t;
+
+struct _LinphoneGeneralState {
+  gstate_t old_state;
+  gstate_t new_state;
+  gstate_group_t group;
+  const char *message;
+};
+typedef struct _LinphoneGeneralState LinphoneGeneralState;
+
+/* retrieve the current state of the specified state group */
+gstate_t gstate_get_state(gstate_group_t group);
+
+/* private: set the initial states */
+void gstate_initialize(void);
+
+/* private: set a new state */
+void gstate_new_state(struct _LinphoneCore *lc, gstate_t new_state, const char *message);
+
 typedef void (*ShowInterfaceCb)(struct _LinphoneCore *lc);
 typedef void (*InviteReceivedCb)(struct _LinphoneCore *lc, const char *from);
 typedef void (*ByeReceivedCb)(struct _LinphoneCore *lc, const char *from);
@@ -314,6 +357,7 @@ typedef void (*NewUnknownSubscriberCb)(struct _LinphoneCore *lc, LinphoneFriend
 typedef void (*AuthInfoRequested)(struct _LinphoneCore *lc, const char *realm, const char *username);
 typedef void (*CallLogUpdated)(struct _LinphoneCore *lc, struct _LinphoneCallLog *newcl);
 typedef void (*TextMessageReceived)(struct _LinphoneCore *lc, LinphoneChatRoom *room, const char *from, const char *message);
+typedef void (*GeneralStateChange)(struct _LinphoneCore *lc, LinphoneGeneralState *gstate);
 
 typedef struct _LinphoneVTable
 {
@@ -334,6 +378,7 @@ typedef struct _LinphoneVTable
 	DisplayQuestionCb display_question;
 	CallLogUpdated call_log_updated;
 	TextMessageReceived text_received;
+	GeneralStateChange general_state;
 } LinphoneCoreVTable;
 
 typedef struct _LCCallbackObj
