@@ -132,39 +132,39 @@ void linphone_notify_recv(LinphoneCore *lc,char *from,int online_status)
 	switch (online_status){
 		case EXOSIP_NOTIFY_PENDING:
 			status=_("Waiting for Approval");
-			img="linphone/sip-wfa.png";
+			img="sip-wfa.png";
 			break;
 		case EXOSIP_NOTIFY_ONLINE:
 			status=_("Online");
-			img="linphone/sip-online.png";
+			img="sip-online.png";
 			break;
 		case EXOSIP_NOTIFY_BUSY:
 			status=_("Busy");
-			img="linphone/sip-busy.png";
+			img="sip-busy.png";
 			break;
 		case EXOSIP_NOTIFY_BERIGHTBACK:
 			status=_("Be Right Back");
-			img="linphone/sip-bifm.png";
+			img="sip-bifm.png";
 			break;
 		case EXOSIP_NOTIFY_AWAY:
 			status=_("Away");
-			img="linphone/sip-away.png";
+			img="sip-away.png";
 			break;
 		case EXOSIP_NOTIFY_ONTHEPHONE:
 			status=_("On The Phone");
-			img="linphone/sip-otp.png";
+			img="sip-otp.png";
 			break;
 		case EXOSIP_NOTIFY_OUTTOLUNCH:
 			status=_("Out To Lunch");
-			img="linphone/sip-otl.png";
+			img="sip-otl.png";
 			break;
 		case EXOSIP_NOTIFY_CLOSED:
 			status=_("Closed");
-			img="linphone/sip-away.png";
+			img="sip-away.png";
 			break;
 		case EXOSIP_NOTIFY_UNKNOWN:
 			status=_("Gone");
-			img="linphone/sip-closed.png";
+			img="sip-closed.png";
 			break;
 		default:
 			ms_warning("Notify status not understood (%i)",online_status);
