@@ -38,10 +38,18 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define MS_VIDEO_SIZE_MAX_W MS_VIDEO_SIZE_4CIF_W
 #define MS_VIDEO_SIZE_MAX_H MS_VIDEO_SIZE_4CIF_H
 
+#define MS_VIDEO_SIZE_NS1_W 324
+#define MS_VIDEO_SIZE_NS1_H 248
+
+
 typedef struct MSVideoSize{
 	int width,height;
 } MSVideoSize;
 
+typedef struct MSRect{
+	int x,y,w,h;
+} MSRect;
+
 #define MS_VIDEO_SIZE_CIF (MSVideoSize){MS_VIDEO_SIZE_CIF_W,MS_VIDEO_SIZE_CIF_H}
 #define MS_VIDEO_SIZE_QCIF (MSVideoSize){MS_VIDEO_SIZE_QCIF_W,MS_VIDEO_SIZE_QCIF_H}
 #define MS_VIDEO_SIZE_4CIF (MSVideoSize){MS_VIDEO_SIZE_4CIF_W,MS_VIDEO_SIZE_4CIF_H}
@@ -49,9 +57,11 @@ typedef struct MSVideoSize{
 #define MS_VIDEO_SIZE_QVGA (MSVideoSize){MS_VIDEO_SIZE_QVGA_W,MS_VIDEO_SIZE_QVGA_H}
 #define MS_VIDEO_SIZE_VGA (MSVideoSize){MS_VIDEO_SIZE_VGA_W,MS_VIDEO_SIZE_VGA_H}
 
+#define MS_VIDEO_SIZE_NS1 (MSVideoSize){MS_VIDEO_SIZE_NS1_W,MS_VIDEO_SIZE_NS1_H}
+
 typedef enum{
 	MS_YUV420P,
-	MS_YV12,
+	MS_YUYV,
 	MS_RGB24,
 	MS_MJPEG
 }MSPixFmt;
@@ -60,8 +70,8 @@ int ms_pix_fmt_to_ffmpeg(MSPixFmt fmt);
 MSPixFmt ffmpeg_pix_fmt_to_ms(int fmt);
 void ms_ffmpeg_check_init();
 
-#define MS_FILTER_SET_VIDEO_SIZE		MS_FILTER_BASE_METHOD(100,MSVideoSize)
-#define MS_FILTER_GET_VIDEO_SIZE		MS_FILTER_BASE_METHOD(101,MSVideoSize)
+#define MS_FILTER_SET_VIDEO_SIZE	MS_FILTER_BASE_METHOD(100,MSVideoSize)
+#define MS_FILTER_GET_VIDEO_SIZE	MS_FILTER_BASE_METHOD(101,MSVideoSize)
 
 #define MS_FILTER_SET_PIX_FMT		MS_FILTER_BASE_METHOD(102,MSPixFmt)
 #define MS_FILTER_GET_PIX_FMT		MS_FILTER_BASE_METHOD(103,MSPixFmt)
