@@ -28,16 +28,16 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 static void 
 ice_sendtest( Socket myFd, StunAddress4 *dest, 
               const StunAtrString *username, const StunAtrString *password, 
-              int testNum, bool verbose , UInt128 *tid);
+              int testNum, bool_t verbose , UInt128 *tid);
 
 static void 
 ice_sendtest( Socket myFd, StunAddress4 *dest, 
               const StunAtrString *username, const StunAtrString *password, 
-              int testNum, bool verbose , UInt128 *tid)
+              int testNum, bool_t verbose , UInt128 *tid)
 {	
-   bool changePort=false;
-   bool changeIP=false;
-   bool discard=false;
+   bool_t changePort=FALSE;
+   bool_t changeIP=FALSE;
+   bool_t discard=FALSE;
 
    StunMessage req;
    char buf[STUN_MAX_MESSAGE_SIZE];
@@ -50,17 +50,17 @@ ice_sendtest( Socket myFd, StunAddress4 *dest,
       case 11:
          break;
       case 2:
-         /* changePort=true; */
-         changeIP=true;
+         /* changePort=TRUE; */
+         changeIP=TRUE;
          break;
       case 3:
-         changePort=true;
+         changePort=TRUE;
          break;
       case 4:
-         changeIP=true;
+         changeIP=TRUE;
          break;
       case 5:
-         discard=true;
+         discard=TRUE;
          break;
       default:
          printf("Test %i is unkown\n", testNum);
@@ -118,7 +118,7 @@ int ice_sound_send_stun_request(RtpSession *session, struct CandidatePair *remot
             StunAddress4 stunServerAddr;
             StunAtrString username;
             StunAtrString password;
-            bool res;
+            bool_t res;
             int  pad_size;
 
             struct CandidatePair *cand_pair = &remote_candidates[pos]; 
@@ -156,10 +156,10 @@ int ice_sound_send_stun_request(RtpSession *session, struct CandidatePair *remot
 
             res = stunParseServerName(cand_pair->remote_candidate.ipaddr,
                 &stunServerAddr);
-            if ( res == true )
+            if ( res == TRUE )
             {
                 stunServerAddr.port = cand_pair->remote_candidate.port;
-                ice_sendtest(media_socket, &stunServerAddr, &username, &password, 1, 0/*false*/,
+                ice_sendtest(media_socket, &stunServerAddr, &username, &password, 1, 0/*FALSE*/,
                     &(cand_pair->tid));
             }
         }
@@ -217,9 +217,9 @@ _ice_get_localip_for (struct sockaddr_storage *saddr, size_t saddr_len, char *lo
 
 int ice_process_stun_message(RtpSession *session, struct CandidatePair *remote_candidates, OrtpEvent *evt)
 {
-    bool switch_to_address = -1;
+    int switch_to_address = -1;
     StunMessage msg;
-    bool res;
+    bool_t res;
     int already_worked_once=-1;
     OrtpEventData *evt_data = ortp_event_get_data(evt);
     mblk_t *mp = evt_data->packet;
@@ -296,8 +296,8 @@ int ice_process_stun_message(RtpSession *session, struct CandidatePair *remote_c
         StunAddress4 secondary;
         StunAddress4 myAddr;
         StunAddress4 myAltAddr;
-        bool changePort = false;
-        bool changeIp = false;
+        bool_t changePort = FALSE;
+        bool_t changeIp = FALSE;
         struct sockaddr_storage name;
         socklen_t namelen;
         char localip[128];
@@ -345,7 +345,7 @@ int ice_process_stun_message(RtpSession *session, struct CandidatePair *remote_c
             &hmacPassword,
             &changePort,
             &changeIp,
-            false );
+            FALSE );
 
         if (!res)
         {
@@ -353,15 +353,15 @@ int ice_process_stun_message(RtpSession *session, struct CandidatePair *remote_c
             return -1;
         }
 
-        if (changePort == true || changeIp == true)
+        if (changePort == TRUE || changeIp == TRUE)
         {
             ms_error("ice.c: STUN request with changePort or changeIP refused.");
             return -1;
         }
 
-        res=true;
-        if ( dest.addr == 0 ) res=false;
-        if ( dest.port == 0 ) res=false;
+        res=TRUE;
+        if ( dest.addr == 0 ) res=FALSE;
+        if ( dest.port == 0 ) res=FALSE;
         if (!res)
         {
             ms_error("ice.c: Missing destination value for response.");
@@ -369,7 +369,7 @@ int ice_process_stun_message(RtpSession *session, struct CandidatePair *remote_c
         }
 
     
-        if (msg.hasUsername!=true || msg.username.sizeValue<=0)
+        if (msg.hasUsername!=TRUE || msg.username.sizeValue<=0)
         {
             /* reply 430 */
             ms_error("ice.c: Missing or bad username value.");
@@ -471,9 +471,9 @@ int ice_process_stun_message(RtpSession *session, struct CandidatePair *remote_c
         {
             char buf[STUN_MAX_MESSAGE_SIZE];            
             int len = sizeof(buf);
-            len = stunEncodeMessage( &resp, buf, len, &hmacPassword,false );
+            len = stunEncodeMessage( &resp, buf, len, &hmacPassword,FALSE );
             if (len)
-                sendMessage( rtp_socket, buf, len, dest.addr, dest.port, false );
+                sendMessage( rtp_socket, buf, len, dest.addr, dest.port, FALSE );
         }
     }
     else
@@ -483,7 +483,7 @@ int ice_process_stun_message(RtpSession *session, struct CandidatePair *remote_c
         StunAddress4 mappedAddr;
         memset(&resp, 0, sizeof(StunMessage));
         res = stunParseMessage((char*)mp->b_rptr, mp->b_wptr-mp->b_rptr,
-            &resp, false );
+            &resp, FALSE );
         if (!res)
         {
             ms_error("ice.c: Bad format for STUN answer.");
