@@ -186,27 +186,29 @@ int ms_list_index(const MSList *list, void *data){
 }
 
 MSList *ms_list_insert_sorted(MSList *list, void *data, int (*compare_func)(const void *, const void*)){
-	MSList *it,*previt;
+	MSList *it,*previt=NULL;
 	MSList *nelem;
 	MSList *ret=list;
 	if (list==NULL) return ms_list_append(list,data);
-	nelem=ms_list_new(data);
-	for(it=list;it!=NULL;it=it->next){
-		previt=it;
-		if (compare_func(data,it->data)<=0){
-			nelem->prev=it->prev;
-			nelem->next=it;
-			if (it->prev!=NULL)
-				it->prev->next=nelem;
-			else{
-				ret=nelem;
+	else{
+		nelem=ms_list_new(data);
+		for(it=list;it!=NULL;it=it->next){
+			previt=it;
+			if (compare_func(data,it->data)<=0){
+				nelem->prev=it->prev;
+				nelem->next=it;
+				if (it->prev!=NULL)
+					it->prev->next=nelem;
+				else{
+					ret=nelem;
+				}
+				it->prev=nelem;
+				return ret;
 			}
-			it->prev=nelem;
-			return ret;
 		}
+		previt->next=nelem;
+		nelem->prev=previt;
 	}
-	previt->next=nelem;
-	nelem->prev=previt;
 	return ret;
 }
 
@@ -392,22 +394,48 @@ void ms_init(){
 		ortp_set_log_level_mask(ORTP_DEBUG|ORTP_MESSAGE|ORTP_WARNING|ORTP_ERROR|ORTP_FATAL);
 	}
 #endif
-
+	ms_message("Registering all filters...");
 	/* register builtin MSFilter's */
 	for (i=0;ms_filter_descs[i]!=NULL;i++){
 		ms_filter_register(ms_filter_descs[i]);
 	}
+	ms_message("Registering all soundcard handlers");
 	/*register SndCardDesc */
 	cm=ms_snd_card_manager_get();
 	for (i=0;ms_snd_card_descs[i]!=NULL;i++){
 		ms_snd_card_manager_register_desc(cm,ms_snd_card_descs[i]);
 	}
-	ms_load_plugins(PACKAGE_PLUGINS_DIR);
-}
 
-extern void ms_snd_card_manager_destroy(void);
+	ms_message("Loading plugins");
+	ms_load_plugins(PACKAGE_PLUGINS_DIR);
+	ms_message("ms_init() done");
+}
 
 void ms_exit(){
 	ms_filter_unregister_all();
 	ms_snd_card_manager_destroy();
 }
+
+void ms_reload_snd_card(MSSndCardDesc *snd_desc){
+	MSSndCardManager *cm;
+	int i;
+
+	ms_snd_card_manager_destroy();
+
+	ms_message("Registering all soundcard handlers");
+	if (snd_desc!=NULL)
+	{
+		cm=ms_snd_card_manager_get();
+		if (cm!=NULL)
+			ms_snd_card_manager_register_desc(cm,snd_desc);
+		return;
+	}
+
+	/*register SndCardDesc */
+	cm=ms_snd_card_manager_get();
+	for (i=0;ms_snd_card_descs[i]!=NULL;i++){
+		ms_snd_card_manager_register_desc(cm,ms_snd_card_descs[i]);
+	}
+
+	return;
+}
