@@ -82,6 +82,7 @@ MSSndCard * ms_snd_card_new(MSSndCardDesc *desc){
 	obj->name=NULL;
 	obj->data=NULL;
 	obj->id=NULL;
+	obj->capabilities=MS_SND_CARD_CAP_CAPTURE|MS_SND_CARD_CAP_PLAYBACK;
 	if (desc->init!=NULL)
 		desc->init(obj);
 	return obj;
@@ -95,6 +96,10 @@ const char *ms_snd_card_get_name(const MSSndCard *obj){
 	return obj->name;
 }
 
+unsigned int ms_snd_card_get_capabilities(const MSSndCard *obj){
+	return obj->capabilities;
+}
+
 const char *ms_snd_card_get_string_id(MSSndCard *obj){
 	if (obj->id==NULL)	obj->id=ms_strdup_printf("%s: %s",obj->desc->driver_type,obj->name);
 	return obj->id;
