@@ -43,6 +43,9 @@ void ms_ticker_init(MSTicker *ticker)
 	ticker->exec_id=0;
 	ticker->get_cur_time_ptr=&get_cur_time;
 	ticker->get_cur_time_data=NULL;
+#ifdef WIN32_TIMERS
+	ticker->TimeEvent=NULL;
+#endif
 	ms_ticker_start(ticker);
 }
 
@@ -237,47 +240,25 @@ static void run_graphs(MSTicker *s, MSList *execution_list, bool_t force_schedul
 #include <sys/timeb.h>
 #endif
 
-#ifdef WIN32
-
-#if !defined(_WIN32_WCE)
-#include <sys/types.h>
-#include <sys/timeb.h>
-#endif
-
-/**
- * timespec structure
- * @struct timespec
- */
-  struct timespec
-  {
-    long tv_sec;
-    long tv_nsec;
-  };
-#endif
-
 static uint64_t get_cur_time(void *unused){
 #if defined(_WIN32_WCE)
 	DWORD timemillis = GetTickCount();
 	return timemillis;
-#else
+#elif defined(WIN32)
+	return timeGetTime() ;
+#elif defined(__MACH__)
 	struct timespec ts;
-#if defined(WIN32)
-	struct _timeb time_val;
-	
-	_ftime (&time_val);
-	ts.tv_sec = time_val.time;
-	ts.tv_nsec = time_val.millitm * 1000000;
-#elif __MACH__
 	struct timeb time_val;
 	
 	ftime (&time_val);
 	ts.tv_sec = time_val.time;
 	ts.tv_nsec = time_val.millitm * 1000000;
+	return (ts.tv_sec*1000LL) + (ts.tv_nsec/1000000LL);
 #else
+	struct timespec ts;
 	if (clock_gettime(CLOCK_REALTIME,&ts)<0){
 		ms_fatal("clock_gettime() doesn't work: %s",strerror(errno));
 	}
-#endif
 	return (ts.tv_sec*1000LL) + (ts.tv_nsec/1000000LL);
 #endif
 }
@@ -293,11 +274,56 @@ static void sleepMs(int ms){
 #endif
 }
 
+static int set_high_prio(void){
+	int precision=2;
+#ifdef WIN32
+	MMRESULT mm;
+	TIMECAPS ptc;
+	mm=timeGetDevCaps(&ptc,sizeof(ptc));
+	if (mm==0){
+		if (ptc.wPeriodMin<precision)
+			ptc.wPeriodMin=precision;
+		else
+			precision = ptc.wPeriodMin;
+		mm=timeBeginPeriod(ptc.wPeriodMin);
+		if (mm!=TIMERR_NOERROR){
+			ms_warning("timeBeginPeriod failed.");
+		}
+		ms_message("win32 timer resolution set to %i ms",ptc.wPeriodMin);
+	}else{
+		ms_warning("timeGetDevCaps failed.");
+	}
+
+	if(!SetThreadPriority(GetCurrentThread(), THREAD_PRIORITY_HIGHEST)){
+		ms_warning("SetThreadPriority() failed (%d)\n", GetLastError());
+	}
+#endif
+	return precision;
+}
+
+static void unset_high_prio(int precision){
+#ifdef WIN32
+	MMRESULT mm;
+
+	if(!SetThreadPriority(GetCurrentThread(), THREAD_PRIORITY_NORMAL)){
+		ms_warning("SetThreadPriority() failed (%d)\n", GetLastError());
+	}
+
+	mm=timeEndPeriod(precision);
+#endif
+}
+
+#ifndef WIN32_TIMERS
+
 void * ms_ticker_run(void *arg)
 {
 	MSTicker *s=(MSTicker*)arg;
 	uint64_t realtime;
 	int lastlate=0;
+	int precision=2;
+
+	precision = set_high_prio();
+
 
 	s->ticks=1;
 	ms_mutex_lock(&s->lock);
@@ -329,10 +355,60 @@ void * ms_ticker_run(void *arg)
 	}
 	ms_cond_signal(&s->cond);
 	ms_mutex_unlock(&s->lock);
+	unset_high_prio(precision);
+	ms_message("MSTicker thread exiting");
 	ms_thread_exit(NULL);
 	return NULL;
 }
 
+#else
+
+void * ms_ticker_run(void *arg)
+{
+	MSTicker *s=(MSTicker*)arg;
+	uint64_t realtime;
+	int precision=2;
+	UINT timerId;
+
+	precision = set_high_prio();
+
+	s->TimeEvent = CreateEvent (NULL, FALSE, FALSE, NULL);
+
+	s->ticks=1;
+	ms_mutex_lock(&s->lock);
+	s->orig=s->get_cur_time_ptr(s->get_cur_time_data);
+
+	timerId = timeSetEvent (s->interval, precision, s->TimeEvent, 0,
+				  TIME_PERIODIC | TIME_CALLBACK_EVENT_SET);
+	while(s->run){
+		DWORD err;
+
+		s->ticks++;
+		run_graphs(s,s->execution_list,FALSE);
+
+		/* elapsed time since origin */
+		s->time = s->get_cur_time_ptr(s->get_cur_time_data)- s->orig;
+
+		ms_mutex_unlock(&s->lock);
+		err = WaitForSingleObject (s->TimeEvent, s->interval*1000 ); /* wake up each diff */
+		if (err==WAIT_FAILED)
+			ms_message("WaitForSingleObject is failing");
+
+		ms_mutex_lock(&s->lock);
+	}
+	ms_cond_signal(&s->cond);
+	ms_mutex_unlock(&s->lock);
+	timeKillEvent (timerId);
+	CloseHandle (s->TimeEvent);
+	s->TimeEvent=NULL;
+	unset_high_prio(precision);
+	ms_message("MSTicker thread exiting");
+	ms_thread_exit(NULL);
+	return NULL;
+}
+
+#endif
+
 void ms_ticker_set_time_func(MSTicker *ticker, MSTickerTimeFunc func, void *user_data){
 	if (func==NULL) func=get_cur_time;
 	/*ms_mutex_lock(&ticker->lock);*/
@@ -342,6 +418,47 @@ void ms_ticker_set_time_func(MSTicker *ticker, MSTickerTimeFunc func, void *user
 	new one may return different times*/
 	ticker->orig=func(user_data)-ticker->time;
 	/*ms_mutex_unlock(&ticker->lock);*/
-	ms_message("ms_ticker_set_time_func: ticker updated.\n");
+	ms_message("ms_ticker_set_time_func: ticker updated.");
 }
 
+static void print_graph(MSFilter *f, MSTicker *s, MSList **unschedulable, bool_t force_schedule){
+	int i;
+	MSQueue *l;
+	if (f->last_tick!=s->ticks ){
+		if (filter_can_process(f,s->ticks) || force_schedule) {
+			/* this is a candidate */
+			f->last_tick=s->ticks;
+			ms_message("print_graphs: %s", f->desc->name);
+			/* now recurse to next filters */		
+			for(i=0;i<f->desc->noutputs;i++){
+				l=f->outputs[i];
+				if (l!=NULL){
+					print_graph(l->next.filter,s,unschedulable, force_schedule);
+				}
+			}
+		}else{
+			/* this filter has not all inputs that have been filled by filters before it. */
+			*unschedulable=ms_list_prepend(*unschedulable,f);
+		}
+	}
+}
+
+static void print_graphs(MSTicker *s, MSList *execution_list, bool_t force_schedule){
+	MSList *it;
+	MSList *unschedulable=NULL;
+	for(it=execution_list;it!=NULL;it=it->next){
+		print_graph((MSFilter*)it->data,s,&unschedulable,force_schedule);
+	}
+	/* filters that are part of a loop haven't been called in process() because one of their input refers to a filter that could not be scheduled (because they could not be scheduled themselves)... Do you understand ?*/
+	/* we resolve this by simply assuming that they must be called anyway 
+	for the loop to run correctly*/
+	/* we just recall run_graphs on them, as if they were source filters */
+	if (unschedulable!=NULL) {
+		print_graphs(s,unschedulable,TRUE);
+		ms_list_free(unschedulable);
+	}
+}
+
+void ms_ticker_print_graphs(MSTicker *ticker){
+	print_graphs(ticker,ticker->execution_list,FALSE);
+}
