@@ -36,9 +36,16 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "mediastreamer2/msvideo.h"
 #include "mediastreamer2/msticker.h"
 #include "mediastreamer2/msv4l.h"
-
 #include "nowebcam.h"
 
+/* From: Logitech QuickCam USB driver */
+#define QC_IOCTLBASE	    220
+/* Get enable workaround for bugs, bitfield */
+#define VIDIOCQCGCOMPATIBLE _IOR ('v',QC_IOCTLBASE+10,int)
+/* Set enable workaround for bugs, bitfield */
+#define VIDIOCQCSCOMPATIBLE _IOWR('v',QC_IOCTLBASE+10,int)
+
+
 typedef struct V4lState{
 	int fd;
 	ms_thread_t thread;
@@ -314,13 +321,18 @@ static int v4l_start(MSFilter *f, void *arg)
 	}
 	if (s->fd<0){
 		ms_error("MSV4l: cannot open video device (%s): %s.",s->dev,strerror(errno));
+		if (!s->usemire){
+			s->pix_fmt=MS_YUV420P;
+			s->fps=1;
+		}
 		return -1;
 	}else{
 #ifdef HAVE_LINUX_VIDEODEV2_H
 		if (v4lv2_configure(s)<0) {/*might not be V4LV2 */
 #else
-		{
+		if (1){
 #endif
+			struct video_capability vidcap;
 			err=v4l_configure(s);
 			if (err<0) 
 			{
@@ -330,6 +342,21 @@ static int v4l_start(MSFilter *f, void *arg)
 				return -1;
 			}
 			reuse_fd=TRUE;
+
+			err=ioctl(s->fd, VIDIOCGCAP, &vidcap);
+			if (err==0)
+			  {
+			    ms_message("MSV4l: Webcam is %s.", vidcap.name);
+			    if (strcasecmp(vidcap.name, "Logitech QuickCam USB")==0)
+			      {
+				int comp_arg=0;
+				err=ioctl(s->fd, VIDIOCQCSCOMPATIBLE, &comp_arg);
+				if (err==0)
+				  {
+				    ms_message("MSV4l: compatibility mode disabled for %s.", vidcap.name);
+				  }
+			      }
+			}
 		}else{
 			ms_message("Device is a video4linux V2 one.");
 			s->v4lv2=TRUE;
@@ -349,11 +376,11 @@ static void v4l_start_capture(V4lState *s){
 static int v4l_stop(MSFilter *f, void *arg){
 	V4lState *s=(V4lState*)f->data;
 	if (s->fd>=0){
-		ms_message("v4l fd %i closed",s->fd);
 		if (!reuse_fd){
 			if (close(s->fd)<0){
 				ms_warning("MSV4l: Could not close(): %s",strerror(errno));
 			}
+			ms_message("v4l fd %i closed",s->fd);
 		}
 		s->fd=-1;
 		s->frame_count=-1;
@@ -459,7 +486,7 @@ static bool_t try_size(V4lState *s, MSVideoSize vsize){
 		return FALSE;
 	}
 	if (s->vsize.width!=win.width || s->vsize.height!=win.height){
-		ms_warning("Capture size is not what we expected: asked for %ix%i and get %ix%i",vsize.width,vsize.height, win.width, win.height);
+		ms_warning("Capture size is not what we expected: asked for %ix%i and get %ix%i",s->vsize.width,s->vsize.height, win.width, win.height);
 	}
 	s->got_vsize.width=win.width;
 	s->got_vsize.height=win.height;
@@ -691,31 +718,8 @@ static mblk_t * v4l_make_mire(V4lState *s){
 }
 
 static mblk_t * v4l_make_nowebcam(V4lState *s){
-	unsigned char *data;
-	unsigned char *p;
-	int i,j,pos,linepos;
-	int starti,startj;
-	if (s->mire==NULL){
-		s->mire=allocb(s->vsize.width*s->vsize.height*3,0);
-		s->mire->b_wptr=s->mire->b_datap->db_lim;
-		memset(s->mire->b_rptr,0,s->mire->b_wptr-s->mire->b_rptr);
-		data=s->mire->b_rptr;
-		p=data;
-		pos=0;
-		starti=(s->vsize.width/2)-(gimp_image.width/2);
-		startj=(s->vsize.height/2)-(gimp_image.height/2);
-		linepos=startj*s->vsize.width*3;
-		for (j=startj;j<startj+gimp_image.height;++j){
-			p=&data[linepos]+(starti*3);
-			for(i=starti;i<starti+gimp_image.width;++i){
-				p[0]=gimp_image.pixel_data[pos];
-				p[1]=gimp_image.pixel_data[pos+1];
-				p[2]=gimp_image.pixel_data[pos+2];
-				p+=3;
-				pos+=3;
-			}
-			linepos+=s->vsize.width*3;
-		}
+	if (s->mire==NULL && s->frame_ind==0){
+		s->mire=ms_load_nowebcam(&s->vsize, -1);
 	}
 	s->frame_ind++;
 	return s->mire;
@@ -831,18 +835,18 @@ static void v4l_process(MSFilter * obj){
 		s->frame_count=0;
 	}
 	cur_frame=((obj->ticker->time-s->start_time)*s->fps/1000.0);
-	if (cur_frame>s->frame_count){
+	if (cur_frame>=s->frame_count){
 		mblk_t *om=NULL;
 		ms_mutex_lock(&s->mutex);
 		/*keep the most recent frame if several frames have been captured */
 		if (s->fd!=-1){
 			om=getq(&s->rq);
 		}else{
-			if (s->usemire)
+			if (s->usemire){
 				om=dupmsg(v4l_make_mire(s));
-			else {
-				om=dupmsg(v4l_make_nowebcam(s));
-				s->fps=1;
+			}else {
+				mblk_t *tmpm=v4l_make_nowebcam(s);
+				if (tmpm) om=dupmsg(tmpm);
 			}
 		}
 		ms_mutex_unlock(&s->mutex);
