@@ -134,6 +134,50 @@ static void size_conv_process(MSFilter *f){
 	}
 }
 
+
+static int sizeconv_set_vsize(MSFilter *f, void*arg){
+	SizeConvState *s=(SizeConvState*)f->data;
+	s->target_vsize=*(MSVideoSize*)arg;
+
+	freemsg(s->om);
+
+	if (s->rsctx!=NULL) {
+		img_resample_close(s->rsctx);
+		s->rsctx=NULL;
+	}
+
+	s->input_vsize.width = MS_VIDEO_SIZE_CIF_W;
+	s->input_vsize.height = MS_VIDEO_SIZE_CIF_H;
+	s->rsctx=NULL;
+	s->in_size=0;
+	s->out_size=avpicture_get_size(PIX_FMT_YUV420P,s->target_vsize.width,s->target_vsize.height);
+	if (cif_yuv_size==0){
+		cif_yuv_size=avpicture_get_size(PIX_FMT_YUV420P,MS_VIDEO_SIZE_CIF_W,MS_VIDEO_SIZE_CIF_H);
+		qcif_yuv_size=avpicture_get_size(PIX_FMT_YUV420P,MS_VIDEO_SIZE_QCIF_W,MS_VIDEO_SIZE_QCIF_H);
+		qvga_yuv_size=avpicture_get_size(PIX_FMT_YUV420P,MS_VIDEO_SIZE_QVGA_W,MS_VIDEO_SIZE_QVGA_H);
+	}
+
+
+	return 0;
+}
+
+#if 0
+static int sizeconv_set_pixfmt(MSFilter *f, void *arg){
+	SizeConvState *s=(SizeConvState*)f->data;
+	PixConvState *s=(PixConvState*)f->data;
+	s->in_fmt=ms_pix_fmt_to_ffmpeg(fmt);
+	return 0;
+}
+#endif
+
+static MSFilterMethod methods[]={
+	{	MS_FILTER_SET_VIDEO_SIZE, sizeconv_set_vsize	},
+#if 0
+	{	MS_FILTER_SET_PIX_FMT,	sizeconv_set_pixfmt	},
+#endif
+	{	0	,	NULL }
+};
+
 #ifdef _MSC_VER
 
 MSFilterDesc ms_size_conv_desc={
@@ -149,7 +193,7 @@ MSFilterDesc ms_size_conv_desc={
 	size_conv_process,
 	size_conv_postprocess,
 	size_conv_uninit,
-	NULL
+	methods
 };
 
 #else
@@ -163,7 +207,8 @@ MSFilterDesc ms_size_conv_desc={
 	.init=size_conv_init,
 	.process=size_conv_process,
 	.postprocess=size_conv_postprocess,
-	.uninit=size_conv_uninit
+	.uninit=size_conv_uninit,
+	.methods=methods
 };
 
 #endif
