@@ -222,6 +222,12 @@ static void prepare_mpeg4(EncState *s){
 	AVCodecContext *c=&s->av_context;
 	c->flags|=CODEC_FLAG_LOW_DELAY;	/*don't use b frames ?*/
 	c->flags|=CODEC_FLAG_AC_PRED;
+	c->flags|=CODEC_FLAG_H263P_UMV;
+	c->flags|=CODEC_FLAG_QPEL;
+	c->flags|=CODEC_FLAG_4MV;
+	c->flags|=CODEC_FLAG_GMC;
+	c->flags|=CODEC_FLAG_LOOP_FILTER;
+	c->flags|=CODEC_FLAG_H263P_SLICE_STRUCT;
 }
 
 static void enc_uninit(MSFilter  *f){
