@@ -29,7 +29,7 @@
 #include "mediastreamer-config.h"
 #endif
 
-extern RtpSession * create_duplex_rtpsession(RtpProfile *profile, int locport,const char *remip,int remport,int payload,int jitt_comp);
+extern RtpSession * create_duplex_rtpsession( int locport, bool_t ipv6);
 
 #define MAX_RTP_SIZE	UDP_MAX_SIZE
 
@@ -102,23 +102,38 @@ static void payload_type_changed(RtpSession *session, unsigned long data){
 	video_stream_change_decoder(stream,pt);
 }
 
-VideoStream *
-video_stream_start (RtpProfile *profile, int locport, const char *remip, int remport,int payload, int jitt_comp,  const char *device)
-{
+VideoStream *video_stream_new(int locport, bool_t use_ipv6){
 	VideoStream *stream = ms_new0 (VideoStream, 1);
+	stream->session=create_duplex_rtpsession(locport,use_ipv6);
+	return stream;
+}
+
+int video_stream_start (VideoStream *stream, RtpProfile *profile, const char *remip, int remport,int payload, int jitt_comp,  const char *device)
+{
 	PayloadType *pt;
+	RtpSession *rtps=stream->session;
 	MSPixFmt format;
 	MSVideoSize vsize=MS_VIDEO_SIZE_CIF;
 	float fps=15;
 
 	pt=rtp_profile_get_payload(profile,payload);
 	if (pt==NULL){
-		video_stream_free(stream);
 		ms_error("videostream.c: undefined payload type.");
-		return NULL;
+		return -1;
 	}
-	stream->session=create_duplex_rtpsession(profile,locport,remip,remport,payload,jitt_comp);
-	rtp_session_enable_adaptive_jitter_compensation(stream->session,TRUE);
+	stream->encoder=ms_filter_create_encoder(pt->mime_type);
+	stream->decoder=ms_filter_create_decoder(pt->mime_type);
+	if ((stream->encoder==NULL) || (stream->decoder==NULL)){
+		/* big problem: we have not a registered codec for this payload...*/
+		ms_error("videostream.c: No codecs available for payload %i:%s.",payload,pt->mime_type);
+		return -1;
+	}
+	
+	rtp_session_set_profile(rtps,profile);
+	if (remport>0) rtp_session_set_remote_addr(rtps,remip,remport);
+	rtp_session_set_payload_type(rtps,payload);
+	rtp_session_set_jitter_compensation(rtps,jitt_comp);
+
 	rtp_session_signal_connect(stream->session,"payload_type_changed",
 			(RtpCallback)payload_type_changed,(unsigned long)stream);
 
@@ -134,25 +149,19 @@ video_stream_start (RtpProfile *profile, int locport, const char *remip, int rem
 	stream->source = ms_filter_new(MS_V4L_ID);
 	stream->tee = ms_filter_new(MS_TEE_ID);
 	stream->sizeconv = ms_filter_new(MS_SIZE_CONV_ID);
-	stream->output=ms_filter_new(MS_SDL_OUT_ID);
+	stream->output=ms_filter_new(MS_VIDEO_OUT_ID);
 
-	stream->encoder=ms_filter_create_encoder(pt->mime_type);
-	stream->decoder=ms_filter_create_decoder(pt->mime_type);
-	if ((stream->encoder==NULL) || (stream->decoder==NULL)){
-		/* big problem: we have not a registered codec for this payload...*/
-		ms_error("videostream.c: No codecs available for payload %i:%s.",payload,pt->mime_type);
-		video_stream_free(stream);
-		return NULL;
-	}
 	
-	/* set parameters to the encoder */
-	if (pt->send_fmtp){
-		ms_filter_call_method(stream->encoder,MS_FILTER_ADD_FMTP,pt->send_fmtp);
-	}
+	
 	if (pt->normal_bitrate>0){
 		ms_message("Limiting bitrate of video encoder to %i bits/s",pt->normal_bitrate);
 		ms_filter_call_method(stream->encoder,MS_FILTER_SET_BITRATE,&pt->normal_bitrate);
 	}
+	/* set parameters to the encoder and decoder*/
+	if (pt->send_fmtp){
+		ms_filter_call_method(stream->encoder,MS_FILTER_ADD_FMTP,pt->send_fmtp);
+		ms_filter_call_method(stream->decoder,MS_FILTER_ADD_FMTP,pt->send_fmtp);
+	}
 	ms_filter_call_method(stream->encoder,MS_FILTER_GET_VIDEO_SIZE,&vsize);
 	ms_filter_call_method(stream->encoder,MS_FILTER_GET_FPS,&fps);
 	ms_message("Setting vsize=%ix%i, fps=%f",vsize.width,vsize.height,fps);
@@ -198,7 +207,7 @@ video_stream_start (RtpProfile *profile, int locport, const char *remip, int rem
 	stream->ticker = ms_ticker_new(); 
 	/* attach it the graph */
 	ms_ticker_attach (stream->ticker, stream->source);
-	return stream;
+	return 0;
 }
 
 
@@ -207,19 +216,21 @@ void
 video_stream_stop (VideoStream * stream)
 {
 
-	ms_ticker_detach(stream->ticker,stream->source);
-	ms_filter_call_method_noarg(stream->source,MS_V4L_STOP);
-
-	rtp_stats_display(rtp_session_get_stats(stream->session),"Video session's RTP statistics");
+	if (stream->ticker){
+		ms_ticker_detach(stream->ticker,stream->source);
+		ms_filter_call_method_noarg(stream->source,MS_V4L_STOP);
 	
-	ms_filter_unlink(stream->source,0,stream->pixconv,0);
-	ms_filter_unlink(stream->pixconv,0,stream->tee,0);
-	ms_filter_unlink(stream->tee,0,stream->encoder,0);
-	ms_filter_unlink(stream->encoder, 0, stream->rtpsend,0);
-	ms_filter_unlink(stream->rtprecv, 0, stream->decoder, 0);
-	ms_filter_unlink(stream->decoder,0,stream->sizeconv,0);
-	ms_filter_unlink(stream->sizeconv,0,stream->output,0);
-	ms_filter_unlink(stream->tee,1,stream->output,1);
+		rtp_stats_display(rtp_session_get_stats(stream->session),"Video session's RTP statistics");
+		
+		ms_filter_unlink(stream->source,0,stream->pixconv,0);
+		ms_filter_unlink(stream->pixconv,0,stream->tee,0);
+		ms_filter_unlink(stream->tee,0,stream->encoder,0);
+		ms_filter_unlink(stream->encoder, 0, stream->rtpsend,0);
+		ms_filter_unlink(stream->rtprecv, 0, stream->decoder, 0);
+		ms_filter_unlink(stream->decoder,0,stream->sizeconv,0);
+		ms_filter_unlink(stream->sizeconv,0,stream->output,0);
+		ms_filter_unlink(stream->tee,1,stream->output,1);
+	}
 	video_stream_free (stream);
 }
 
@@ -242,7 +253,7 @@ VideoStream * video_preview_start(const char *device){
 
 	/* creates the filters */
 	stream->source = ms_filter_new(MS_V4L_ID);
-	stream->output = ms_filter_new(MS_SDL_OUT_ID);
+	stream->output = ms_filter_new(MS_VIDEO_OUT_ID);
 
 	/* configure the filters */
 	ms_filter_call_method_noarg(stream->source,MS_V4L_START);
@@ -258,7 +269,7 @@ VideoStream * video_preview_start(const char *device){
 	}
 	format=MS_YUV420P;
 	ms_filter_call_method(stream->output,MS_FILTER_SET_PIX_FMT,&format);
-	
+	ms_filter_call_method(stream->output,MS_FILTER_SET_VIDEO_SIZE,&vsize);
 	/* and then connect all */
 	ms_filter_link(stream->source,0, stream->pixconv,0);
 	ms_filter_link(stream->pixconv,0,stream->output,0);
@@ -280,20 +291,33 @@ void video_preview_stop(VideoStream *stream){
 
 VideoStream * video_stream_send_only_start(RtpProfile *profile, int locport, const char *remip, int remport, int payload, const char *device)
 {
-	VideoStream *stream = ms_new0 (VideoStream, 1);
+	VideoStream *stream = video_stream_new(locport,ms_is_ipv6(remip));
+	RtpSession *rtps=stream->session;
 	PayloadType *pt;
 	MSPixFmt format;
 	MSVideoSize vsize=MS_VIDEO_SIZE_CIF;
 	float fps=7;
 	
+
+	rtp_session_set_profile(rtps,profile);
+	if (remport>0) rtp_session_set_remote_addr(rtps,remip,remport);
+	rtp_session_set_payload_type(rtps,payload);
+	rtp_session_set_jitter_compensation(rtps,60);
+
 	pt=rtp_profile_get_payload(profile,payload);
 	if (pt==NULL){
 		video_stream_free(stream);
 		ms_error("videostream.c: undefined payload type.");
 		return NULL;
 	}
-	stream->session=create_duplex_rtpsession(profile,locport,remip,remport,payload,60);
-	/*rtp_session_enable_adaptive_jitter_compensation(stream->session,FALSE);*/
+	stream->encoder=ms_filter_create_encoder(pt->mime_type);
+	if ((stream->encoder==NULL)){
+		/* big problem: we have not a registered codec for this payload...*/
+		video_stream_free(stream);
+		ms_error("videostream.c: No codecs available for payload %i.",payload);
+		return NULL;
+	}
+	
 	
 	/* creates two rtp filters to recv send streams (remote part) */
 	rtp_session_set_recv_buf_size(stream->session,MAX_RTP_SIZE);
@@ -304,13 +328,7 @@ VideoStream * video_stream_send_only_start(RtpProfile *profile, int locport, con
 	/* creates the filters */
 	stream->source = ms_filter_new(MS_V4L_ID);
 	stream->pixconv= ms_filter_new(MS_PIX_CONV_ID);
-	stream->encoder=ms_filter_create_encoder(pt->mime_type);
-	if ((stream->encoder==NULL)){
-		/* big problem: we have not a registered codec for this payload...*/
-		video_stream_free(stream);
-		ms_error("videostream.c: No codecs available for payload %i.",payload);
-		return NULL;
-	}
+	
 
 	/* configure the filters */
 	if (pt->send_fmtp)
