@@ -21,6 +21,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define DISABLE_SPEEX
 #endif
 
+#ifndef WINSND_BUFLEN
+#define WINSND_BUFLEN 320
+#endif
+
 #ifndef MAX_WAVEHDR
 #define MAX_WAVEHDR 6
 #endif
@@ -49,6 +53,7 @@ MSFilter *ms_winsnd_write_new(MSSndCard *card);
 typedef struct WinSndData{
 	char *pcmdev;
 	char *mixdev;
+	int   devid;
 
     int sound_err;
     WAVEFORMATEX wfx;
@@ -56,6 +61,7 @@ typedef struct WinSndData{
     char waveoutbuffer[30][3200];
     HWAVEOUT waveoutdev;
     int buffer_playing;
+	int pos_whdr;
 
     WAVEHDR waveinhdr[30];
     HWAVEIN waveindev;
@@ -76,6 +82,9 @@ typedef struct WinSndData{
 #endif
 
 	uint64_t bytes_read;
+	int32_t stat_input;
+	int32_t stat_output;
+	int32_t stat_notplayed;
 } WinSndData;
 
 static uint64_t winsnd_get_cur_time( void *data){
@@ -105,6 +114,12 @@ SpeakerCallback (HWAVEOUT _waveoutdev, UINT uMsg, DWORD dwInstance,
         wHdr = (WAVEHDR *) dwParam1;
         device = (WinSndData *)dwInstance;
         device->buffer_playing--;
+		if (device->stat_output==0)
+		{
+			device->stat_input=1; /* reset */
+			device->stat_notplayed=0;
+		}
+		device->stat_output++;
         break;
       default:
         break;
@@ -140,6 +155,8 @@ WaveInCallback (HWAVEIN waveindev, UINT uMsg, DWORD dwInstance, DWORD dwParam1,
       case WIM_DATA:
         wHdr = (WAVEHDR *) dwParam1;
 
+		device->bytes_read+=wHdr->dwBytesRecorded;
+
         if (!device->read_started && !device->write_started)
           {
             mr = waveInUnprepareHeader (device->waveindev, (LPWAVEHDR) wHdr, sizeof (WAVEHDR));
@@ -158,7 +175,6 @@ WaveInCallback (HWAVEIN waveindev, UINT uMsg, DWORD dwInstance, DWORD dwParam1,
             }
             return;
         }
-	device->bytes_read+=wHdr->dwBytesRecorded;
     	ms_mutex_lock(&device->mutex);
 		if (device->read_started)
         {
@@ -182,6 +198,7 @@ WaveInCallback (HWAVEIN waveindev, UINT uMsg, DWORD dwInstance, DWORD dwParam1,
 #endif
 			rm->b_wptr+=wHdr->dwBufferLength;
 			putq(&device->rq,rm);
+			device->stat_input++;
 		    rm=NULL;
         }
     	ms_mutex_unlock(&device->mutex);
@@ -241,7 +258,7 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
         /* BUG: on ne connait pas la taille des frames a recevoir... 
         on utilise enc_frame_per_packet au lien de dec_frame_per_packet */
 
-        device->waveouthdr[i].dwBufferLength = device->rate/8000 * 320;
+        device->waveouthdr[i].dwBufferLength = device->rate/8000 * WINSND_BUFLEN;
         /* 480 pour 98 (speex) */
         device->waveouthdr[i].dwFlags = 0;
         device->waveouthdr[i].dwUser = i;
@@ -285,7 +302,7 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
         memset (&(device->waveinhdr[i]), 0, sizeof (device->waveinhdr[i]));
         device->waveinhdr[i].lpData = device->waveinbuffer[i];
         /* frameSize */
-        device->waveinhdr[i].dwBufferLength = device->rate/8000 * 320;
+        device->waveinhdr[i].dwBufferLength = device->rate/8000 * WINSND_BUFLEN;
         device->waveinhdr[i].dwFlags = 0;
         device->waveinhdr[i].dwUser = i;
         mr = waveInPrepareHeader (device->waveindev, &(device->waveinhdr[i]),             
@@ -330,7 +347,7 @@ static int winsnd_open(WinSndData *device, int devnumber, int bits,int stereo, i
 	}
 #endif
 #endif
-	device->bytes_read=0;
+
 	mr = waveInStart (device->waveindev);
     if (mr != MMSYSERR_NOERROR)
     {
@@ -419,6 +436,7 @@ static void winsnd_set_source(MSSndCard *card, MSSndCardCapture source)
 static void winsnd_init(MSSndCard *card){
 	WinSndData *d=ms_new(WinSndData,1);
     memset(d, 0, sizeof(WinSndData));
+	d->bytes_read=0;
 	d->pcmdev=NULL;
 	d->mixdev=NULL;
     d->sound_err=-1; /* not opened */
@@ -434,6 +452,9 @@ static void winsnd_init(MSSndCard *card){
 #ifndef DISABLE_SPEEX
 	d->pst=0;
 #endif
+	d->stat_input=0;
+	d->stat_output=0;
+	d->stat_notplayed=0;
 }
 
 static void winsnd_uninit(MSSndCard *card){
@@ -480,16 +501,18 @@ static  MSSndCard *winsnd_dup(MSSndCard *obj){
 	WinSndData *dobj=(WinSndData*)obj->data;
 	dcard->pcmdev=ms_strdup(dobj->pcmdev);
 	dcard->mixdev=ms_strdup(dobj->mixdev);
+	dcard->devid=dobj->devid;
 	card->name=ms_strdup(obj->name);
 	return card;
 }
 
-static MSSndCard *winsnd_card_new(const char *pcmdev, const char *mixdev){
+static MSSndCard *winsnd_card_new(const char *pcmdev, const char *mixdev, int id){
 	MSSndCard *card=ms_snd_card_new(&winsnd_card_desc);
 	WinSndData *d=(WinSndData*)card->data;
 	d->pcmdev=ms_strdup(pcmdev);
 	d->mixdev=ms_strdup(mixdev);
 	card->name=ms_strdup(pcmdev);
+	d->devid=id;
 	return card;
 }
 
@@ -512,10 +535,10 @@ static void winsnd_detect(MSSndCardManager *m){
 	        snprintf(mixdev,sizeof(mixdev),"%s",caps.szPname);
             if (item == 0)
             {
-		        card=winsnd_card_new(pcmdev,mixdev);
+		        card=winsnd_card_new(pcmdev,mixdev, item-1);
 		        ms_snd_card_manager_add_card(m,card);
             }
-			card=winsnd_card_new(pcmdev,mixdev);
+			card=winsnd_card_new(pcmdev,mixdev, item);
 			ms_snd_card_manager_add_card(m,card);
         }
     }
@@ -524,140 +547,46 @@ static void winsnd_detect(MSSndCardManager *m){
 static void * winsnd_thread(void *p){
 	MSSndCard *card=(MSSndCard*)p;
 	WinSndData *d=(WinSndData*)card->data;
-	int bsize=0;
+	int bsize=d->rate/8000 * 320;
 	uint8_t *rtmpbuff=NULL;
 	uint8_t *wtmpbuff=NULL;
 	int err;
-#if 0
-	mblk_t *rm=NULL;
-#endif
 
-    MMRESULT mr = NOERROR;
+	MMRESULT mr = NOERROR;
     int pos_whdr=0;
-	int devnumber=-1;
-	const MSList *elem = ms_snd_card_manager_get_list(ms_snd_card_manager_get());
 
-	/* look for devicenumber for card */
-	for (;elem!=NULL;elem=elem->next){
-		MSSndCard *acard=(MSSndCard*)elem->data;
-		if (card==acard)
-		{
-			break;
-		}
-		devnumber++;
-	}
-
-	d->sound_err=winsnd_open(d, devnumber, d->bits,d->stereo,d->rate,&bsize);
+	d->stat_input=0;
+	d->stat_output=0;
+	d->stat_notplayed=0;
+	d->sound_err=winsnd_open(d, d->devid, d->bits,d->stereo,d->rate,&bsize);
 	if (d->sound_err==0){
 		rtmpbuff=(uint8_t*)alloca(bsize);
 		wtmpbuff=(uint8_t*)alloca(bsize);
 	}
 	while(d->read_started || d->write_started){
 		if (d->sound_err==0){
-#if 0
-			if (d->read_started){
-                if (rm==NULL) rm=allocb(bsize,0);
-
-                /* get data from callback */
-				//err=read(d->pcmfd,rm->b_wptr,bsize);
-                err=-1;
-
-				if (err<0){
-					ms_warning("Fail to read %i bytes from soundcard: %s",
-					bsize,strerror(errno));
-				}else{
-					rm->b_wptr+=err;
-					putq(&d->rq,rm);
-					rm=NULL;
-				}
-			}else {
-				int sz;
-                //sz = read(d->pcmfd,rtmpbuff,bsize);
-                sz=-1;
-				if( sz!=bsize) ms_warning("sound device read returned %i !",sz);
-			}
-#endif
 			if (d->write_started){
+#if 0
+                if (d->stat_output>0 && d->buffer_playing==0)
+				{
+                    ms_error("No data currently playing in sound card" );
+				}
+				if (d->stat_output>0 && (d->stat_input-d->stat_output>10 || d->stat_input-d->stat_output<-10))
+                    ms_error("Not perfectly synchronized (input-output=%i)", d->stat_input-d->stat_output);
+#endif
 
-                if (d->buffer_playing<4 && d->buffer_playing<MAX_WAVEHDR)
-                {
-					/* remove extra buffer when latency is increasing:
-					this often happen with USB device */
+				while (d->buffer_playing<6 && d->buffer_playing<MAX_WAVEHDR)
+				{
 					ms_mutex_lock(&d->mutex);
-					if (d->bufferizer->size>=bsize*7){
-                        ms_warning("Extra data for sound card removed (%ims)", 2*(bsize*20)/320);
-					    err=ms_bufferizer_read(d->bufferizer,wtmpbuff,bsize);
-					    err=ms_bufferizer_read(d->bufferizer,wtmpbuff,bsize);
-					}
 				    err=ms_bufferizer_read(d->bufferizer,wtmpbuff,bsize);
 					ms_mutex_unlock(&d->mutex);
-				    if (err==bsize){
+				    if (err!=bsize)
+						break;
 
-                        /* write to sound devide! */
-                        //err=write(d->pcmfd,wtmpbuff,bsize);
-                        memcpy (d->waveouthdr[pos_whdr].lpData, wtmpbuff, bsize);
-
-                        mr = waveOutWrite (d->waveoutdev,
-                            &(d->waveouthdr[pos_whdr]),
-                            sizeof (d->waveouthdr[pos_whdr]));
-
-                        if (mr != MMSYSERR_NOERROR)
-                        {
-                            if (mr == WAVERR_STILLPLAYING)
-                            {
-                                /* retry later */
-                                /* data should go back to queue */
-                                /* TODO */
-                                ms_warning("sound device write STILL_PLAYING (waveOutWrite:0x%i)", mr);
-                            }
-                            else
-                            {
-                                ms_warning("sound device write returned (waveOutWrite:0x%i)", mr);
-                            }
-                        }
-                        else
-                        {
-                            d->buffer_playing++;
-                            pos_whdr++;
-                            if (pos_whdr == MAX_WAVEHDR)
-                                pos_whdr = 0;   /* loop over the prepared blocks */
-                        }
-
-
-					    if (err<0){
-#if !defined(_WIN32_WCE)
-						    ms_warning("Fail to write %i bytes from soundcard: %s",
-							    bsize,strerror(errno));
-#else
-						    ms_warning("Fail to write %i bytes from soundcard: %i",
-							    bsize,WSAGetLastError());
-#endif
-					    }
-				    }
-					else
-					{
-							Sleep(10);
-					}
-                }
-                else
-                {
 					ms_mutex_lock(&d->mutex);
-					if (d->bufferizer->size>=bsize*4){
-                        ms_warning("Extra data for sound card removed (%ims)", 3*(bsize*20)/320);
-					    err=ms_bufferizer_read(d->bufferizer,wtmpbuff,bsize);
-					    err=ms_bufferizer_read(d->bufferizer,wtmpbuff,bsize);
-					    err=ms_bufferizer_read(d->bufferizer,wtmpbuff,bsize);
-					}
-					ms_mutex_unlock(&d->mutex);
-                    Sleep(10);
-                }
-			}else {
-                if (d->buffer_playing<3 && d->buffer_playing<MAX_WAVEHDR)
-                {
-				    memset(wtmpbuff,0,bsize);
-    				
+                    /* write to sound devide! */
                     memcpy (d->waveouthdr[pos_whdr].lpData, wtmpbuff, bsize);
-                    //sz = write(d->pcmfd,wtmpbuff,bsize);
+
                     mr = waveOutWrite (d->waveoutdev,
                         &(d->waveouthdr[pos_whdr]),
                         sizeof (d->waveouthdr[pos_whdr]));
@@ -683,11 +612,51 @@ static void * winsnd_thread(void *p){
                         if (pos_whdr == MAX_WAVEHDR)
                             pos_whdr = 0;   /* loop over the prepared blocks */
                     }
-			    }
-                else
+					ms_mutex_unlock(&d->mutex);
+
+
+				    if (err<0){
+#if !defined(_WIN32_WCE)
+					    ms_warning("Fail to write %i bytes from soundcard: %s",
+						    bsize,strerror(errno));
+#else
+					    ms_warning("Fail to write %i bytes from soundcard: %i",
+						    bsize,WSAGetLastError());
+#endif
+				    }
+				}
+
+                if (d->buffer_playing==6 || d->buffer_playing==MAX_WAVEHDR)
                 {
-                    Sleep(10);
-                }
+					int discarded=0;
+					ms_mutex_lock(&d->mutex);
+					while (d->bufferizer->size>=bsize){
+						discarded++;
+						d->stat_notplayed++;
+					    err=ms_bufferizer_read(d->bufferizer,wtmpbuff,bsize);
+					}
+					ms_mutex_unlock(&d->mutex);
+					if (discarded>0)
+						ms_error("Extra data for sound card removed (%ims), (playing: %i) (input-output: %i)", (discarded*20*320)/320, d->buffer_playing, d->stat_input - d->stat_output);
+				}
+#if !defined(_WIN32_WCE)
+				Sleep(5);
+#endif
+#if defined(_WIN32_WCE)
+				Sleep(10);
+#endif
+			}else {
+				int discarded=0;
+				/* don't think this is usefull, anyway... */
+				ms_mutex_lock(&d->mutex);
+				while (d->bufferizer->size>=bsize){
+					discarded++;
+				    err=ms_bufferizer_read(d->bufferizer,wtmpbuff,bsize);
+				}
+				ms_mutex_unlock(&d->mutex);
+				if (discarded>0)
+					ms_error("Extra data for sound card removed (%ims), (playing: %i) (input-output: %i)", (discarded*20)/320, d->buffer_playing, d->stat_input - d->stat_output);
+			    Sleep(10);
             }
 		}else Sleep(10);
 	}
@@ -695,6 +664,7 @@ static void * winsnd_thread(void *p){
         int i;
         int count=0;
         /* close sound card */
+		ms_error("Shutting down sound device (playing: %i) (input-output: %i) (notplayed: %i)", d->buffer_playing, d->stat_input - d->stat_output, d->stat_notplayed);
 
         /* unprepare buffer */
         for (i = 0; i < MAX_WAVEHDR; i++)
@@ -747,6 +717,9 @@ static void * winsnd_thread(void *p){
         }
 		d->sound_err=-1;
 	}
+	d->stat_input=0;
+	d->stat_output=0;
+	d->stat_notplayed=0;
 	return NULL;
 }
 
@@ -834,6 +807,7 @@ static void winsnd_write_postprocess(MSFilter *f){
 static void winsnd_write_process(MSFilter *f){
 	MSSndCard *card=(MSSndCard*)f->data;
 	mblk_t *m;
+
 	while((m=ms_queue_get(f->inputs[0]))!=NULL){
 		winsnd_put(card,m);
 	}
@@ -853,10 +827,33 @@ static int set_nchannels(MSFilter *f, void *arg){
 	return 0;
 }
 
+static int winsnd_get_stat_input(MSFilter *f, void *arg){
+	MSSndCard *card=(MSSndCard*)f->data;
+	WinSndData *d=(WinSndData*)card->data;
+
+	return d->stat_input;
+}
+
+static int winsnd_get_stat_ouptut(MSFilter *f, void *arg){
+	MSSndCard *card=(MSSndCard*)f->data;
+	WinSndData *d=(WinSndData*)card->data;
+
+	return d->stat_output;
+}
+
+static int winsnd_get_stat_discarded(MSFilter *f, void *arg){
+	MSSndCard *card=(MSSndCard*)f->data;
+	WinSndData *d=(WinSndData*)card->data;
+
+	return d->stat_notplayed;
+}
 
 static MSFilterMethod winsnd_methods[]={
 	{	MS_FILTER_SET_SAMPLE_RATE	, set_rate	},
 	{	MS_FILTER_SET_NCHANNELS		, set_nchannels	},
+	{	MS_FILTER_GET_STAT_INPUT, winsnd_get_stat_input },
+	{	MS_FILTER_GET_STAT_OUTPUT, winsnd_get_stat_ouptut },
+	{	MS_FILTER_GET_STAT_DISCARDED, winsnd_get_stat_discarded },
 	{	0				, NULL		}
 };
 
