@@ -201,14 +201,14 @@ void run_media_streams(int localport,  const char *remote_ip, int remoteport, in
 	}else{
 #ifdef VIDEO_ENABLED
 		printf("Starting video stream.\n");
-		video=video_stream_start(profile,
-					localport,
+		video=video_stream_new(localport, ms_is_ipv6(remote_ip));
+		video_stream_start(video,profile,
 					remote_ip,
 					remoteport,
 					payload,
 					jitter,
 					"/dev/video0");
-		if (video) session=video->session;
+		session=video->session;
 #else
 		printf("Error: video support not compiled.\n");
 #endif
@@ -218,7 +218,15 @@ void run_media_streams(int localport,  const char *remote_ip, int remoteport, in
 	{
 		/* sleep until we receive SIGINT */
 #ifdef WIN32
-        Sleep(1000);
+		int n;
+        MSG msg;
+        for(n=0;n<100;++n){
+        	Sleep(10);
+			while (PeekMessage(&msg, NULL, 0, 0,1)){
+        		TranslateMessage(&msg);
+        		DispatchMessage(&msg);
+			}
+		}
 #else
 		sleep(1);
 #endif
